@@ -1567,6 +1567,10 @@ class Cast(Expression):
     arg_types = {"this": True, "to": True}
 
 
+class Distinct(Expression):
+    pass
+
+
 class Extract(Expression):
     arg_types = {"this": True, "expression": True}
 
@@ -1579,6 +1583,10 @@ class Interval(Expression):
     arg_types = {"this": True, "unit": False}
 
 
+class IgnoreNulls(Expression):
+    pass
+
+
 class TryCast(Cast):
     pass
 
@@ -1705,7 +1713,7 @@ class ConcatWs(Func):
 
 
 class Count(AggFunc):
-    arg_types = {"this": False, "distinct": False}
+    pass
 
 
 class DateAdd(Func):
